@@ -2,10 +2,14 @@ class ManifestooException(Exception):  # noqa: N818
     """Base class of all manifestoo_core exceptions."""
 
 
-class UnsupportedOdooVersion(ManifestooException):
+class UnsupportedOdooSeries(ManifestooException):
     pass
 
 
+# compatibility alias
+UnsupportedOdooVersion = UnsupportedOdooSeries
+
+
 class UnsupportedManifestVersion(ManifestooException):
     pass
 
@@ -36,3 +40,11 @@ class AddonNotFoundNotADirectory(AddonNotFound):
 
 class AddonNotFoundInvalidManifest(AddonNotFound):
     pass
+
+
+class InvalidDistributionName(ManifestooException):
+    pass
+
+
+class UnknownPostVersionStrategy(ManifestooException):
+    pass
