@@ -7,12 +7,14 @@ from .exceptions import InvalidManifest
 T = TypeVar("T")
 VT = TypeVar("VT")
 
-__all__ = ["Manifest", "InvalidManifest", "get_manifest_path"]
+__all__ = ["Manifest", "InvalidManifest", "get_manifest_path", "MANIFEST_NAMES"]
+
+MANIFEST_NAMES = ("__manifest__.py", "__openerp__.py", "__terp__.py")
 
 
 def _check_str(value: Any) -> str:
     if not isinstance(value, str):
-        raise TypeError()
+        raise TypeError
     return value
 
 
@@ -24,22 +26,24 @@ def _check_optional_str(value: Any) -> Optional[str]:
 
 def _check_bool(value: Any) -> bool:
     if not isinstance(value, bool):
-        raise TypeError()
+        raise TypeError
     return value
 
 
 def _check_list(value: Any, item_checker: Callable[[Any], T]) -> List[T]:
     if not isinstance(value, list):
-        raise TypeError()
+        raise TypeError
     map(item_checker, value)
     return value
 
 
 def _check_dict(
-    value: Any, key_checker: Callable[[Any], T], value_checker: Callable[[Any], VT]
+    value: Any,
+    key_checker: Callable[[Any], T],
+    value_checker: Callable[[Any], VT],
 ) -> Dict[T, VT]:
     if not isinstance(value, dict):
-        raise TypeError()
+        raise TypeError
     for k, v in value.items():
         key_checker(k)
         value_checker(v)
@@ -61,7 +65,7 @@ def get_manifest_path(addon_dir: Path) -> Optional[Path]:
 
     Returns None if no manifest file is found.
     """
-    for manifest_name in ("__manifest__.py", "__openerp__.py", "__terp__.py"):
+    for manifest_name in MANIFEST_NAMES:
         manifest_path = addon_dir / manifest_name
         if manifest_path.is_file():
             return manifest_path
@@ -69,7 +73,10 @@ def get_manifest_path(addon_dir: Path) -> Optional[Path]:
 
 
 class Manifest:
+    """Represent an Odoo manifest file."""
+
     def __init__(self, manifest_dict: Dict[str, Any]) -> None:
+        """Do not use this contructor, use the from_* classmethods instead."""
         self.manifest_dict = manifest_dict
 
     def _get(self, key: str, checker: Callable[[Any], T], default: T) -> T:
@@ -86,37 +93,73 @@ class Manifest:
 
     @property
     def name(self) -> Optional[str]:
+        """The name field."""
         return self._get("name", _check_optional_str, default=None)
 
+    @property
+    def summary(self) -> Optional[str]:
+        """The value of the summary field."""
+        return self._get("summary", _check_optional_str, default=None)
+
+    @property
+    def description(self) -> Optional[str]:
+        """The value of the description field."""
+        return self._get("description", _check_optional_str, default=None)
+
     @property
     def version(self) -> Optional[str]:
+        """The value of the version field."""
         return self._get("version", _check_optional_str, default=None)
 
     @property
     def installable(self) -> bool:
+        """The value of the installable field if set, else True."""
         return self._get("installable", _check_bool, default=True)
 
     @property
     def depends(self) -> List[str]:
+        """The value of the depends field if set, else []."""
         return self._get("depends", _check_list_of_str, default=[])
 
     @property
     def external_dependencies(self) -> Dict[str, List[str]]:
+        """The value of the external_dependencies field if set, else {}."""
         return self._get(
-            "external_dependencies", _check_dict_of_list_of_str, default={}
+            "external_dependencies",
+            _check_dict_of_list_of_str,
+            default={},
         )
 
     @property
-    def license(self) -> Optional[str]:  # noqa: A003
+    def license(self) -> Optional[str]:
+        """The value of the license field."""
         return self._get("license", _check_optional_str, default=None)
 
+    @property
+    def author(self) -> Optional[str]:
+        """The value of the author field."""
+        return self._get("author", _check_optional_str, default=None)
+
+    @property
+    def category(self) -> Optional[str]:
+        """The value of the category field."""
+        return self._get("category", _check_optional_str, default=None)
+
+    @property
+    def website(self) -> Optional[str]:
+        """The value of the website field."""
+        return self._get("website", _check_optional_str, default=None)
+
     @property
     def development_status(self) -> Optional[str]:
+        """The value of the development_status field."""
         return self._get("development_status", _check_optional_str, default=None)
 
     @classmethod
     def from_dict(
-        cls, manifest_dict: Dict[Any, Any], source: str = "<manifest>"
+        cls,
+        manifest_dict: Dict[Any, Any],
+        source: str = "<manifest>",
     ) -> "Manifest":
         """Parse a manifest dictionary into a :class:`Manifest` object.
 
