@@ -3,6 +3,7 @@ from enum import Enum
 from typing import Optional, Set
 
 from .addons_set import AddonsSet
+from .exceptions import UnsupportedOdooSeries
 
 __all__ = [
     "OdooSeries",
@@ -12,6 +13,9 @@ __all__ = [
 ]
 
 
+MIN_VERSION_PARTS = 5
+
+
 class OdooSeries(str, Enum):
     """Enum representing an Odoo Series (also known as Version)."""
 
@@ -24,6 +28,21 @@ class OdooSeries(str, Enum):
     v14_0 = "14.0"
     v15_0 = "15.0"
     v16_0 = "16.0"
+    v17_0 = "17.0"
+
+    @classmethod
+    def from_str(cls, value: str, context: Optional[str] = None) -> "OdooSeries":
+        """Get the OdooSeries from a string.
+
+        Raise UnsupportedOdooSeries if the string is not recognized.
+        """
+        try:
+            return cls(value)
+        except ValueError as e:
+            msg = f"Unsupported Odoo Series: {value}"
+            if context:
+                msg = f"{msg} in {context}"
+            raise UnsupportedOdooSeries(msg) from e
 
 
 class OdooEdition(str, Enum):
@@ -39,7 +58,7 @@ def detect_from_addon_version(version: str) -> Optional[OdooSeries]:
     Returns ``None`` if the version is not recognized.
     """
     parts = version.split(".")
-    if len(parts) < 5:
+    if len(parts) < MIN_VERSION_PARTS:
         return None
     try:
         return OdooSeries(".".join(parts[:2]))
