@@ -6,24 +6,31 @@ import pytest
 from pkg_metadata import msg_to_json
 
 from manifestoo_core.exceptions import (
+    InvalidDistributionName,
     UnsupportedManifestVersion,
-    UnsupportedOdooVersion,
+    UnsupportedOdooSeries,
 )
 from manifestoo_core.metadata import (
     POST_VERSION_STRATEGY_DOT_N,
     POST_VERSION_STRATEGY_NINETYNINE_DEVN,
     POST_VERSION_STRATEGY_NONE,
     POST_VERSION_STRATEGY_P1_DEVN,
+    _author_email,
     _filter_odoo_addon_dependencies,
+    _no_nl,
+    addon_name_to_distribution_name,
+    addon_name_to_requirement,
+    distribution_name_to_addon_name,
     metadata_from_addon_dir,
 )
+from manifestoo_core.odoo_series import OdooSeries
 
 
 def _no_none(d: Dict[str, Any]) -> Dict[str, Any]:
     return {k: v for k, v in d.items() if v is not None}
 
 
-def _m(
+def _m(  # noqa: PLR0913 too many arguments
     tmp_path: Path,
     *,
     addon_dir_name: str = "addon1",
@@ -37,7 +44,7 @@ def _m(
     external_dependencies: Optional[Dict[str, List[str]]] = None,
     website: Optional[str] = None,
     author: Optional[str] = None,
-    license: Optional[str] = None,  # noqa: A002
+    license: Optional[str] = None,
     development_status: Optional[str] = None,
     # options
     depends_override: Optional[Dict[str, str]] = None,
@@ -45,6 +52,7 @@ def _m(
         Dict[str, Dict[str, Union[str, List[str]]]]
     ] = None,
     external_dependencies_only: Optional[bool] = None,
+    odoo_series_override: Optional[str] = None,
     odoo_version_override: Optional[str] = None,
     post_version_strategy_override: Optional[str] = None,
     precomputed_metadata_file: Optional[Path] = None,
@@ -56,20 +64,20 @@ def _m(
     manifest_path.write_text(
         repr(
             _no_none(
-                dict(
-                    name=name,
-                    version=version,
-                    summary=summary,
-                    description=description,
-                    depends=depends,
-                    external_dependencies=external_dependencies,
-                    website=website,
-                    author=author,
-                    license=license,
-                    development_status=development_status,
-                )
-            )
-        )
+                {
+                    "name": name,
+                    "version": version,
+                    "summary": summary,
+                    "description": description,
+                    "depends": depends,
+                    "external_dependencies": external_dependencies,
+                    "website": website,
+                    "author": author,
+                    "license": license,
+                    "development_status": development_status,
+                },
+            ),
+        ),
     )
     if readme_rst:
         readme_path = addon_dir / "README.rst"
@@ -77,32 +85,33 @@ def _m(
     return msg_to_json(
         metadata_from_addon_dir(
             addon_dir,
-            options=dict(
-                depends_override=depends_override,
-                external_dependencies_override=external_dependencies_override,
-                external_dependencies_only=external_dependencies_only,
-                odoo_version_override=odoo_version_override,
-                post_version_strategy_override=post_version_strategy_override,
-            ),
+            options={
+                "depends_override": depends_override,
+                "external_dependencies_override": external_dependencies_override,
+                "external_dependencies_only": external_dependencies_only,
+                "odoo_series_override": odoo_series_override,
+                "odoo_version_override": odoo_version_override,
+                "post_version_strategy_override": post_version_strategy_override,
+            },
             precomputed_metadata_file=precomputed_metadata_file,
-        )
+        ),
     )
 
 
 def test_basic(tmp_path: Path) -> None:
-    assert _m(tmp_path) == dict(
-        name="odoo14-addon-addon1",
-        version="14.0.1.0.0",
-        summary="Addon 1",
-        requires_dist=["odoo>=14.0a,<14.1dev"],
-        requires_python=">=3.6",
-        classifier=[
+    assert _m(tmp_path) == {
+        "name": "odoo14-addon-addon1",
+        "version": "14.0.1.0.0",
+        "summary": "Addon 1",
+        "requires_dist": ["odoo>=14.0a,<14.1dev"],
+        "requires_python": ">=3.6",
+        "classifier": [
             "Programming Language :: Python",
             "Framework :: Odoo",
             "Framework :: Odoo :: 14.0",
         ],
-        metadata_version="2.2",
-    )
+        "metadata_version": "2.1",
+    }
 
 
 @pytest.mark.parametrize(
@@ -116,7 +125,7 @@ def test_basic(tmp_path: Path) -> None:
         ("13.0", ["odoo>=13.0a,<13.1dev"]),
         ("14.0", ["odoo>=14.0a,<14.1dev"]),
         ("15.0", ["odoo>=15.0a,<15.1dev"]),
-        ("16.0", ["odoo>=16.0a,<16.1dev"]),  # TODO >=16.0dev ?
+        ("16.0", ["odoo>=16.0a,<16.1dev"]),
     ],
 )
 def test_requires_odoo(tmp_path: Path, odoo_series: str, expected: List[str]) -> None:
@@ -165,7 +174,7 @@ def test_name_prefix(tmp_path: Path, odoo_series: str, expected_prefix: str) ->
 def test_depends_core_addon(tmp_path: Path) -> None:
     """A dependency on a core addon should be ignored."""
     assert _m(tmp_path, version="14.0.1.0.0", depends=["base"])["requires_dist"] == [
-        "odoo>=14.0a,<14.1dev"
+        "odoo>=14.0a,<14.1dev",
     ]
 
 
@@ -207,7 +216,10 @@ def test_depends_core_addon(tmp_path: Path) -> None:
     ],
 )
 def test_depends_noncore_addon(
-    tmp_path: Path, odoo_series: str, depends: List[str], expected: List[str]
+    tmp_path: Path,
+    odoo_series: str,
+    depends: List[str],
+    expected: List[str],
 ) -> None:
     """A dependency on a non-core addon appears in requires_dist."""
     requires_dist = _m(tmp_path, version=f"{odoo_series}.1.0.0", depends=depends)[
@@ -264,13 +276,13 @@ def test_external_dependencies_override_multi(tmp_path: Path) -> None:
         tmp_path,
         external_dependencies={"python": ["lxml"]},
         external_dependencies_override={
-            "python": {"lxml": ["lxml>=3.8.0", "something"]}
+            "python": {"lxml": ["lxml>=3.8.0", "something"]},
         },
     )["requires_dist"] == ["lxml>=3.8.0", "odoo>=14.0a,<14.1dev", "something"]
 
 
-def test_odoo_version_unsupported(tmp_path: Path) -> None:
-    with pytest.raises(UnsupportedOdooVersion):
+def test_odoo_series_unsupported(tmp_path: Path) -> None:
+    with pytest.raises(UnsupportedOdooSeries):
         _m(tmp_path, version="45.0.1.0.0")
 
 
@@ -286,6 +298,12 @@ def test_odoo_version_override(tmp_path: Path) -> None:
     ] == ["odoo>=14.0a,<14.1dev"]
 
 
+def test_odoo_series_override(tmp_path: Path) -> None:
+    assert _m(tmp_path, version="45.0.1.0.0", odoo_series_override="14.0")[
+        "requires_dist"
+    ] == ["odoo>=14.0a,<14.1dev"]
+
+
 def test_summary_defaults_to_name(tmp_path: Path) -> None:
     assert _m(tmp_path, name="addon1")["summary"] == "addon1"
 
@@ -295,13 +313,15 @@ def test_summary_from_summary(tmp_path: Path) -> None:
 
 
 def test_description(
-    tmp_path: Path, description: str = "A description\n\nwith two lines"
+    tmp_path: Path,
+    description: str = "A description\n\nwith two lines",
 ) -> None:
     assert _m(tmp_path, description=description)["description"] == description
 
 
 def test_description_from_readme(
-    tmp_path: Path, readme_rst: str = "A readme\n\nwith two lines"
+    tmp_path: Path,
+    readme_rst: str = "A readme\n\nwith two lines",
 ) -> None:
     assert _m(tmp_path, readme_rst=readme_rst)["description"] == readme_rst
 
@@ -408,7 +428,9 @@ def test_classifiers(tmp_path: Path, odoo_series: str) -> None:
     ],
 )
 def test_classifiers_license(
-    tmp_path: Path, license: str, expected_license: str  # noqa: A002
+    tmp_path: Path,
+    license: str,  # shadowing Python builtin
+    expected_license: str,
 ) -> None:
     assert expected_license in _m(tmp_path, license=license)["classifier"]
 
@@ -425,7 +447,9 @@ def test_classifiers_license(
     ],
 )
 def test_classifiers_development_status(
-    tmp_path: Path, development_status: str, expected_development_status: str
+    tmp_path: Path,
+    development_status: str,
+    expected_development_status: str,
 ) -> None:
     assert (
         expected_development_status
@@ -433,7 +457,7 @@ def test_classifiers_development_status(
     )
 
 
-def test_license(tmp_path: Path, license: str = "AGPL-3") -> None:  # noqa: A002
+def test_license(tmp_path: Path, license: str = "AGPL-3") -> None:
     assert _m(tmp_path, license=license)["license"] == license
 
 
@@ -463,12 +487,13 @@ def _make_git_addon(
     addon_dir = tmp_path / addon_name
     addon_dir.mkdir()
     addon_dir.joinpath("__manifest__.py").write_text(
-        f"{{'name': '{addon_name}', 'version': '{manifest_version}'}}"
+        f"{{'name': '{addon_name}', 'version': '{manifest_version}'}}",
     )
     addon_dir.joinpath("__init__.py").touch()
     subprocess.check_call(["git", "init"], cwd=addon_dir)
     subprocess.check_call(
-        ["git", "config", "user.email", "test@example.com"], cwd=addon_dir
+        ["git", "config", "user.email", "test@example.com"],
+        cwd=addon_dir,
     )
     subprocess.check_call(["git", "config", "user.name", "test"], cwd=addon_dir)
     subprocess.check_call(["git", "add", "."], cwd=addon_dir)
@@ -530,8 +555,8 @@ def test_git_post_version(
     metadata = msg_to_json(
         metadata_from_addon_dir(
             addon_dir,
-            options=dict(post_version_strategy_override=post_version_strategy_override),
-        )
+            options={"post_version_strategy_override": post_version_strategy_override},
+        ),
     )
     assert metadata["version"] == expected_version
 
@@ -558,14 +583,16 @@ def test_git_post_version_uncommitted_change(
     expected_version: str,
 ) -> None:
     addon_dir = _make_git_addon(
-        tmp_path, manifest_version=manifest_version, post_commits=post_commits
+        tmp_path,
+        manifest_version=manifest_version,
+        post_commits=post_commits,
     )
     addon_dir.joinpath("README.rst").write_text("stuff")
     metadata = msg_to_json(
         metadata_from_addon_dir(
             addon_dir,
-            options=dict(post_version_strategy_override=post_version_strategy_override),
-        )
+            options={"post_version_strategy_override": post_version_strategy_override},
+        ),
     )
     assert metadata["version"] == expected_version
 
@@ -585,20 +612,20 @@ def test_git_post_version_bad_manifest_in_history(
 ) -> None:
     addon_dir = _make_git_addon(tmp_path, manifest_version="16.0.1.1.0")
     addon_dir.joinpath("__manifest__.py").write_text(
-        "{syntaxerror, 'version': '16.0.1.2.0'}"
+        "{syntaxerror, 'version': '16.0.1.2.0'}",
     )
     subprocess.check_call(["git", "add", "__manifest__.py"], cwd=addon_dir)
     subprocess.check_call(["git", "commit", "-m", "bad manifest"], cwd=addon_dir)
     addon_dir.joinpath("__manifest__.py").write_text(
-        "{'name': 'A', 'version': '16.0.1.3.0'}"
+        "{'name': 'A', 'version': '16.0.1.3.0'}",
     )
     subprocess.check_call(["git", "add", "__manifest__.py"], cwd=addon_dir)
     subprocess.check_call(["git", "commit", "-m", "good manifest"], cwd=addon_dir)
     metadata = msg_to_json(
         metadata_from_addon_dir(
             addon_dir,
-            options=dict(post_version_strategy_override=post_version_strategy_override),
-        )
+            options={"post_version_strategy_override": post_version_strategy_override},
+        ),
     )
     assert metadata["version"] == "16.0.1.3.0"
 
@@ -618,15 +645,15 @@ def test_git_post_version_good_manifest_in_history(
 ) -> None:
     addon_dir = _make_git_addon(tmp_path, manifest_version="16.0.1.1.0")
     addon_dir.joinpath("__manifest__.py").write_text(
-        "{'name': 'A', 'version': '16.0.1.2.0'}"
+        "{'name': 'A', 'version': '16.0.1.2.0'}",
     )
     subprocess.check_call(["git", "add", "__manifest__.py"], cwd=addon_dir)
     subprocess.check_call(["git", "commit", "-m", "good manifest"], cwd=addon_dir)
     metadata = msg_to_json(
         metadata_from_addon_dir(
             addon_dir,
-            options=dict(post_version_strategy_override=post_version_strategy_override),
-        )
+            options={"post_version_strategy_override": post_version_strategy_override},
+        ),
     )
     assert metadata["version"] == "16.0.1.2.0"
 
@@ -648,15 +675,15 @@ def test_git_post_version_no_manifest_in_history(
     subprocess.check_call(["git", "rm", "__manifest__.py"], cwd=addon_dir)
     subprocess.check_call(["git", "commit", "-m", "no manifest"], cwd=addon_dir)
     addon_dir.joinpath("__manifest__.py").write_text(
-        "{'name': 'A', 'version': '16.0.1.2.0'}"
+        "{'name': 'A', 'version': '16.0.1.2.0'}",
     )
     subprocess.check_call(["git", "add", "__manifest__.py"], cwd=addon_dir)
     subprocess.check_call(["git", "commit", "-m", "good manifest"], cwd=addon_dir)
     metadata = msg_to_json(
         metadata_from_addon_dir(
             addon_dir,
-            options=dict(post_version_strategy_override=post_version_strategy_override),
-        )
+            options={"post_version_strategy_override": post_version_strategy_override},
+        ),
     )
     assert metadata["version"] == "16.0.1.2.0"
 
@@ -680,6 +707,66 @@ def test_git_post_version_no_manifest_in_history(
     ],
 )
 def test_filter_odoo_addon_dependencies(
-    dependencies: List[str], expected: List[str]
+    dependencies: List[str],
+    expected: List[str],
 ) -> None:
     assert list(_filter_odoo_addon_dependencies(dependencies)) == expected
+
+
+def test_distribution_name_to_addon_name() -> None:
+    assert distribution_name_to_addon_name("odoo14-addon-addon1") == "addon1"
+    assert distribution_name_to_addon_name("odoo-addon-addon1") == "addon1"
+    assert distribution_name_to_addon_name("odoo-addon-addon-1") == "addon_1"
+    assert distribution_name_to_addon_name("odoo-addon-addon_1") == "addon_1"
+    with pytest.raises(InvalidDistributionName):
+        distribution_name_to_addon_name("odoo14-addon-")
+    with pytest.raises(InvalidDistributionName):
+        distribution_name_to_addon_name("addon1")
+
+
+def test_addon_name_to_distribution_name() -> None:
+    assert (
+        addon_name_to_distribution_name("addon1", OdooSeries.v14_0)
+        == "odoo14-addon-addon1"
+    )
+    assert (
+        addon_name_to_distribution_name("addon_1", OdooSeries.v16_0)
+        == "odoo-addon-addon_1"
+    )
+
+
+def test_addon_name_to_requirement() -> None:
+    assert (
+        addon_name_to_requirement("addon1", OdooSeries.v14_0) == "odoo14-addon-addon1"
+    )
+    assert (
+        addon_name_to_requirement("addon1", OdooSeries.v16_0)
+        == "odoo-addon-addon1>=16.0dev,<16.1dev"
+    )
+
+
+def test_get_author_email() -> None:
+    assert (
+        _author_email("Odoo Community Association (OCA)")
+        == "support@odoo-community.org"
+    )
+    assert (
+        _author_email("Odoo Community Association (OCA), ACSONE SA/NV")
+        == "support@odoo-community.org"
+    )
+    assert _author_email("ACSONE SA/NV") is None
+
+
+@pytest.mark.parametrize(
+    ("s", "expected"),
+    [
+        ("", ""),
+        (None, None),
+        ("   ", ""),
+        (" \n ", ""),
+        ("a", "a"),
+        ("   a\nb\n", "a b"),
+    ],
+)
+def test_no_nl(s: Optional[str], expected: Optional[str]) -> None:
+    assert _no_nl(s) == expected
